import { Meta, StoryObj } from '@storybook/react';

import { Header } from '.';

const meta: Meta<typeof Header> = {
  title: 'Components/Header',
  component: Header,
  parameters: {
    exclude: ['solanaLogo', 'menus'],
    hideNoControlsWarning: true,
  },
};

export default meta;
type Story = StoryObj<typeof Header>;

export const header: Story = {
  args: {
    solanaLogo: '/images/logos/solanaLogoHeader.png',
    menus: [
      {
        heading: 'Learn',
        colorScheme: 'green',
        menuItems: [
          {
            heading: 'Start Here',
            menuItemType: 'copyOnly',
            icon: 'content-delivery-network',
            subMenus: [
              {
                title: 'Blockchain and Solana 101',
                description: 'The basics on all things Solana and web3.',
                url: '/',
              },
              {
                title: 'Intro to NFTs',
                description: 'Everything you need to know about NFTs on Solana',
                url: '/',
              },
              {
                title: 'Environmental Impact',
                description: 'How Solana is supporting a greener Web3',
                url: '/',
              },
            ],
          },
        ],
      },
      {
        heading: 'Build',
        colorScheme: 'yellow',
        menuItems: [
          {
            heading: 'Developers',
            menuItemType: 'copyOnly',
            icon: 'content-delivery-network',
            subMenus: [
              {
                title: 'Dev Learn Center',
                description: 'Start learning how to build today.',
                url: '/',
              },
              {
                title: 'Solana Documentation',
                description: 'Official Solana and SPL docs.',
                url: '/',
              },
              {
                title: 'NFT Documentation',
                description: 'What you can build with Metaplex.',
                url: '/',
              },
              {
                title: 'Hackathon',
                description: 'Kickstart your crypto journey.',
                url: '/',
              },
            ],
          },
          {
            heading: 'Use Cases',
            menuItemType: 'copyOnly',
            icon: 'sub-volume-carbon',
            subMenus: [
              {
                title: 'NFTs',
                url: '/',
              },
              {
                title: 'DeFi',
                url: '/',
              },
              {
                title: 'Payments',
                url: '/',
              },
              {
                title: 'Gaming',
                url: '/',
              },
              {
                title: 'DAOs',
                url: '/',
              },
            ],
          },
        ],
      },
      {
        heading: 'Network',
        colorScheme: 'purple',
        menuItems: [
          {
            heading: 'Resources',
            menuItemType: 'copyOnly',
            icon: 'content-delivery-network',
            subMenus: [
              {
                title: 'Become a Validator',
                description: 'Help run the Solana network.',
                url: '/',
              },
              {
                title: 'RPC Providers',
                description: 'Build crypto apps that scale.',
                url: '/',
              },
              {
                title: 'Network Status',
                description: 'Network performance and status.',
                url: '/',
              },
            ],
          },
          {
            heading: 'Inspect',
            menuItemType: 'copyOnly',
            icon: 'sub-volume-carbon',
            subMenus: [
              {
                title: 'Solscan',
                description: 'Explore Solana blockchain in real time.',
                url: '/',
              },
              {
                title: 'SolanaFM',
                description: 'Solana blockchain explorer and indexer.',
                url: '/',
              },
            ],
          },
        ],
      },
      {
        heading: 'Community',
        colorScheme: 'pink',
        menuItems: [
          {
            heading: 'Get Involved',
            menuItemType: 'copyOnly',
            icon: 'carbon-for-ibm',
            subMenus: [
              {
                title: 'News',
                description: 'The latest in the Solana ecosystem.',
                url: '/',
              },
              {
                title: 'Events',
                description: 'Experience the Solana community, in real life.',
                url: '/',
              },
              {
                title: 'The Collective',
                description: 'Help the greater ecosystem.',
                url: '/',
              },
              {
                title: 'Community Resource Hub',
                description: 'How to join in.',
                url: '/',
              },
            ],
          },
          {
            heading: 'Breakpoint',
            menuItemType: 'image',
            subMenus: [
              {
                title: 'Breakpoint 2023',
                description: 'Oct 30 - Nov 3, 2023',
                imageSource: '/images/breakpoint-image.png',
                secondDescription: 'Amsterdam, Netherlands',
                url: '/',
              },
            ],
          },
        ],
      },
    ],
  },
};
